@@ -6,8 +6,9 @@
 #' @description
 #' Computes a Fisher confidence interval for a population Pearson correlation  
 #' or partial correlation with s control variables. Set s = 0 for a Pearson 
-#' correlation. This function uses an estimated correlation as input. Use the
-#' cor.test function for a Pearson correlation with raw data input.
+#' correlation. A bias adjustmentment is used to reduce the bias of the Fisher
+#' transformed correlation. This function uses an estimated correlation as 
+#' input. Use the cor.test function for raw data input.
 #'
 #'  
 #' @param  alpha 	alpha level for 1-alpha confidence
@@ -33,7 +34,7 @@
 #'
 #' # Should return:
 #' #      Estimate        SE        LL        UL
-#' # [1,]    0.536 0.1018149 0.3028333 0.7086249
+#' # [1,]    0.536 0.1018149 0.2978573 0.7058914
 #'  
 #' 
 #' @importFrom stats qnorm
@@ -42,7 +43,7 @@ ci.cor <- function(alpha, cor, s, n) {
  z <- qnorm(1 - alpha/2)
  se <- sqrt((1 - cor^2)^2/(n - 1))
  se.z <- sqrt(1/((n - s - 3)))
- zr <- log((1 + cor)/(1 - cor))/2
+ zr <- log((1 + cor)/(1 - cor))/2 - cor/(2*(n - 1))
  ll0 <- zr - z*se.z
  ul0 <- zr + z*se.z
  ll <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
@@ -118,7 +119,8 @@ ci.spcor <- function(alpha, cor, r2, n) {
 #'
 #' @description
 #' Computes a confidence interval for a difference in population Pearson 
-#' correlations in a 2-group design.
+#' correlations in a 2-group design. A bias adjustmentment is used to 
+#' reduce the bias of each Fisher transformed correlation. 
 #'
 #'  
 #' @param  alpha	alpha level for 1-alpha confidence
@@ -144,7 +146,7 @@ ci.spcor <- function(alpha, cor, r2, n) {
 #'
 #' # Should return:
 #' #      Estimate         LL        UL
-#' # [1,]    0.084 0.02795506 0.1457103
+#' # [1,]    0.084 0.02803246 0.1463609
 #'  
 #' 
 #' @importFrom stats qnorm
@@ -153,13 +155,13 @@ ci.cor2 <- function(alpha, cor1, cor2, n1, n2) {
  z <- qnorm(1 - alpha/2)
  diff <- cor1 - cor2
  se1 <- sqrt(1/((n1 - 3)))
- zr1 <- log((1 + cor1)/(1 - cor1))/2
+ zr1 <- log((1 + cor1)/(1 - cor1))/2 - cor1/(2*(n1 - 1))
  ll0 <- zr1 - z*se1
  ul0 <- zr1 + z*se1
  ll1 <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
  ul1 <- (exp(2*ul0) - 1)/(exp(2*ul0) + 1)
  se2 <- sqrt(1/((n2 - 3)))
- zr2 <- log((1 + cor2)/(1 - cor2))/2
+ zr2 <- log((1 + cor2)/(1 - cor2))/2 - cor2/(2*(n2 - 1))
  ll0 <- zr2 - z*se2
  ul0 <- zr2 + z*se2
  ll2 <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
@@ -179,7 +181,8 @@ ci.cor2 <- function(alpha, cor1, cor2, n1, n2) {
 #' @description 
 #' Computes a confidence interval for a difference in population Pearson 
 #' correlations that are estimated from the same sample and have one 
-#' variable in common.
+#' variable in common. A bias adjustmentment is used to reduce the bias
+#' of each Fisher transformed correlation. 
 #'
 #'  
 #' @param  alpha  alpha level for 1-alpha confidence
@@ -205,7 +208,7 @@ ci.cor2 <- function(alpha, cor1, cor2, n1, n2) {
 #'
 #' # Should return:
 #' #      Estimate         LL      UL
-#' # [1,]    0.217 0.01366766 0.41594
+#' # [1,]    0.217 0.01323072 0.415802
 #'  
 #' 
 #' @importFrom stats qnorm
@@ -214,13 +217,13 @@ ci.cor.dep <- function(alpha, cor1, cor2, cor12, n) {
  z <- qnorm(1 - alpha/2)
  diff <- cor1 - cor2
  se1 <- sqrt(1/((n - 3)))
- zr1 <- log((1 + cor1)/(1 - cor1))/2
+ zr1 <- log((1 + cor1)/(1 - cor1))/2 - cor1/(2*(n - 1))
  ll0 <- zr1 - z*se1
  ul0 <- zr1 + z*se1
  ll1 <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
  ul1 <- (exp(2*ul0) - 1)/(exp(2*ul0) + 1)
  se2 <- sqrt(1/((n - 3)))
- zr2 <- log((1 + cor2)/(1 - cor2))/2
+ zr2 <- log((1 + cor2)/(1 - cor2))/2 - cor2/(2*(n - 1))
  ll0 <- zr2 - z*se2
  ul0 <- zr2 + z*se2
  ll2 <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
@@ -716,9 +719,9 @@ ci.fisher <- function(alpha, cor, se) {
 #' The Monte Carlo method is general in that the slope estimates and standard 
 #' errors do not need to be OLS estimates with homoscedastic standard errors. 
 #' For example, LAD slope estimates and their standard errors, OLS slope 
-#' estimates and heteroscedastic standard errors, or distribution-free 
-#' Theil-Sen slope estimates with McKean-Schrader standard errors also could
-#' be used. 
+#' estimates and heteroscedastic standard errors, distribution-free 
+#' Theil-Sen slope estimates with McKean-Schrader standard errors, or 
+#' standardized slopes with robust standard errors also could be used.
 #'
 #'  
 #' @param  alpha  alpha level for 1-alpha confidence  
@@ -739,7 +742,7 @@ ci.fisher <- function(alpha, cor, se) {
 #' @examples
 #' ci.indirect (.05, 2.48, 1.92, .586, .379)
 #'
-#' # Should return:
+#' # Should return (within sampling error for CI):
 #' #      Estimate       SE       LL       UL
 #' # [1,]   4.7616 1.625282 2.178812 7.972262
 #'  
@@ -752,7 +755,7 @@ ci.indirect <- function(alpha, b1, b2, se1, se2) {
  y1 <- rnorm(k, b1, se1)
  y2 <- rnorm(k, b2, se2)
  y <- sort(y1*y2)
- se <- sqrt((b1*se1)^2 + (b2*se2)^2)
+ se <- sqrt((b1*se2)^2 + (b2*se1)^2)
  ll <- y[c]
  ul <- y[k - c + 1]
  out <- t(c(b1*b2, se, ll, ul))
@@ -1467,3 +1470,205 @@ random.yx <- function(n, my, mx, sdy, sdx, cor, dec) {
  colnames(out) <- c("y", "x")
  return(out)
 }
+
+
+#  sim.ci.cor ===============================================================
+#' Simulates confidence interval coverage probability for a Pearson
+#' correlation
+#'
+#'                               
+#' @description
+#' Performs a computer simulation of confidence interval performance for a 
+#' Pearson correlation. A bias adjustment is used to reduce the bias of the
+#' Fisher transformed Pearson correlation. Sample data can be generated 
+#' from bivariate population distributions with five different marginal 
+#' distributions. All distributions are scaled to have standard deviations
+#' of 1.0. Bivariate random data with specified marginal skewness and
+#' kurtosis are generated using the unonr function in the mnonr package. 
+#'
+#'
+#' @param   alpha     alpha level for 1-alpha confidence
+#' @param   n         sample size 
+#' @param   cor       population Pearson correlation
+#' @param   dist1     type of distribution at level 1 (1, 2, 3, 4, or 5)
+#' @param   dist2     type of distribution at level 2 (1, 2, 3, 4, or 5)
+#' * 1 = Gaussian (skewness = 0 and excess kurtosis = 0) 
+#' * 2 = platykurtic (skewness = 0 and excess kurtosis = -1.2)
+#' * 3 = leptokurtic (skewness = 0 and excess kurtsois = 6)
+#' * 4 = moderate skew (skewness = 1 and excess kurtosis = 1.5)
+#' * 5 = large skew (skewness = 2 and excess kurtosis = 6)
+#' @param   rep       number of Monte Carlo samples
+#'  
+#' 
+#' @return
+#' Returns a 1-row matrix. The columns are:
+#' * Coverage - probability of confidence interval including population mean  
+#' * Lower Error - probability of lower limit greater than population mean
+#' * Upper Error - probability of upper limit less than population mean
+#' * Ave CI Width - average confidence interval width
+#'
+#'
+#' @examples
+#' sim.ci.cor(.05, 30, .7, 4, 5, 1000)
+#'
+#' # Should return (within sampling error):
+#' #      Coverage Lower Error Upper Error Ave CI Width
+#' # [1,]  0.93815     0.05125      0.0106    0.7778518
+#'
+#'
+#' @importFrom stats qt
+#' @importFrom mnonr unonr
+#' @export
+sim.ci.cor <- function(alpha, n, cor, dist1, dist2, rep) {
+ zcrit <- qnorm(1 - alpha/2)
+ if (dist1 == 1) {
+   skw1 <- 0; kur1 <- 0
+ } else if (dist1 == 2) {
+   skw1 <- 0; kur1 <- -1.2
+ } else if (dist1 == 3) {
+   skw1 <- 0; kur1 <- 6
+ } else if (dist1 == 4) {
+   skw1 <- .75; kur1 <- .86
+ } else {
+   skw1 <- 1.41; kur1 <- 3
+ }
+ if (dist2 == 1) {
+   skw2 <- 0; kur2 <- 0
+ } else if (dist2 == 2) {
+   skw2 <- 0; kur2 <- -1.2
+ } else if (dist2 == 3) {
+   skw2 <- 0; kur2 <- 6
+ } else if (dist2 == 4) {
+   skw2 <- 1; kur2 <- 1.5
+ } else {
+   skw2 <- 2; kur2 <- 6
+ }
+ V <- matrix(c(1, cor, cor, 1), 2, 2)
+ w <- 0; k <- 0; e1 <-0; e2 <- 0
+ repeat {
+   k <- k + 1
+   y <- unonr(n, c(0, 0), V, skewness = c(skw1, skw2), kurtosis = c(kur1, kur2))
+   R <- cor(y)
+   r <- R[1,2]
+   zr <- log((1 + r)/(1 - r))/2 - r/(2*(n - 1))
+   se.z <- sqrt(1/((n - 3)))
+   ll0 <- zr - zcrit*se.z
+   ul0 <- zr + zcrit*se.z
+   ll <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
+   ul <- (exp(2*ul0) - 1)/(exp(2*ul0) + 1)
+   w0 <- ul - ll
+   c1 <- as.integer(ll > cor)
+   c2 <- as.integer(ul < cor)
+   e1 <- e1 + c1
+   e2 <- e2 + c2
+   w <- w + w0
+   if (k == rep) {break}
+ }
+ width <- w/rep
+ cov <- 1 - (e1 + e2)/rep
+ out <- t(c(cov, e1/rep, e2/rep, width))
+ colnames(out) <- c("Coverage", "Lower Error", "Upper Error", "Ave CI Width")
+ return(out)
+}
+
+
+#  sim.ci.spear ===============================================================
+#' Simulates confidence interval coverage probability for a Spearman
+#' correlation
+#'
+#' @description
+#' Performs a computer simulation of confidence interval performance for a 
+#' Spearman correlation. Sample data can be generated from bivariate population
+#' distributions with five different marginal distributions. All distributions
+#' are scaled to have standard deviations of 1.0. Bivariate random data with 
+#' specified marginal skewness and kurtosis are generated using the unonr 
+#' function in the mnonr package. 
+#'
+#'
+#' @param   alpha     alpha level for 1-alpha confidence
+#' @param   n         sample size 
+#' @param   cor       population Spearman correlation
+#' @param   dist1     type of distribution at level 1 (1, 2, 3, 4, or 5)
+#' @param   dist2     type of distribution at level 2 (1, 2, 3, 4, or 5)
+#' * 1 = Gaussian (skewness = 0 and excess kurtosis = 0) 
+#' * 2 = platykurtic (skewness = 0 and excess kurtosis = -1.2)
+#' * 3 = leptokurtic (skewness = 0 and excess kurtsois = 6)
+#' * 4 = moderate skew (skewness = 1 and excess kurtosis = 1.5)
+#' * 5 = large skew (skewness = 2 and excess kurtosis = 6)
+#' @param   rep      number of Monte Carlo samples
+#'  
+#' 
+#' @return
+#' Returns a 1-row matrix. The columns are:
+#' * Coverage - probability of confidence interval including population mean  
+#' * Lower Error - probability of lower limit greater than population mean
+#' * Upper Error - probability of upper limit less than population mean
+#' * Ave CI Width - average confidence interval width
+#'
+#'
+#' @examples
+#' sim.ci.spear(.05, 30, .7, 4, 5, 1000)
+#'
+#' # Should return (within sampling error):
+#' #      Coverage Lower Error Upper Error Ave CI Width
+#' # [1,]  0.96235     0.01255      0.0251    0.4257299
+#'
+#'
+#' @importFrom stats qt
+#' @importFrom mnonr unonr
+#' @export
+sim.ci.spear <- function(alpha, n, cor, dist1, dist2, rep) {
+ zcrit <- qnorm(1 - alpha/2)
+ if (dist1 == 1) {
+   skw1 <- 0; kur1 <- 0
+ } else if (dist1 == 2) {
+   skw1 <- 0; kur1 <- -1.2
+ } else if (dist1 == 3) {
+   skw1 <- 0; kur1 <- 6
+ } else if (dist1 == 4) {
+   skw1 <- .75; kur1 <- .86
+ } else {
+   skw1 <- 1.41; kur1 <- 3
+ }
+ if (dist2 == 1) {
+   skw2 <- 0; kur2 <- 0
+ } else if (dist2 == 2) {
+   skw2 <- 0; kur2 <- -1.2
+ } else if (dist2 == 3) {
+   skw2 <- 0; kur2 <- 6
+ } else if (dist2 == 4) {
+   skw2 <- 1; kur2 <- 1.5
+ } else {
+   skw2 <- 2; kur2 <- 6
+ }
+ V <- matrix(c(1, cor, cor, 1), 2, 2)
+ y <- unonr(100000, c(0, 0), V, skewness = c(skw1, skw2), kurtosis = c(kur1, kur2))
+ popR <- cor(y, method = "spearman")
+ popspear <- popR[1,2]
+ w <- 0; k <- 0; e1 <-0; e2 <- 0
+ repeat {
+   k <- k + 1
+   y <- unonr(n, c(0, 0), V, skewness = c(skw1, skw2), kurtosis = c(kur1, kur2))
+   R <- cor(y, method = "spearman")
+   r <- R[1,2]
+   zr <- log((1 + r)/(1 - r))/2 
+   se.z <- sqrt((1 + r^2/2)*(1 - r^2)^2/(n - 3))
+   ll0 <- zr - zcrit*se.z/(1 - r^2)
+   ul0 <- zr + zcrit*se.z/(1 - r^2)
+   ll <- (exp(2*ll0) - 1)/(exp(2*ll0) + 1)
+   ul <- (exp(2*ul0) - 1)/(exp(2*ul0) + 1)
+   w0 <- ul - ll
+   c1 <- as.integer(ll > popspear)
+   c2 <- as.integer(ul < popspear)
+   e1 <- e1 + c1
+   e2 <- e2 + c2
+   w <- w + w0
+   if (k == rep) {break}
+ }
+ width <- w/rep
+ cov <- 1 - (e1 + e2)/rep
+ out <- t(c(cov, e1/rep, e2/rep, width))
+ colnames(out) <- c("Coverage", "Lower Error", "Upper Error", "Ave CI Width")
+ return(out)
+}
+
